summaryrefslogtreecommitdiffstats
path: root/certmanager/lib/ui/kdhorizontalline.h
diff options
context:
space:
mode:
Diffstat (limited to 'certmanager/lib/ui/kdhorizontalline.h')
-rw-r--r--certmanager/lib/ui/kdhorizontalline.h17
1 files changed, 9 insertions, 8 deletions
diff --git a/certmanager/lib/ui/kdhorizontalline.h b/certmanager/lib/ui/kdhorizontalline.h
index 0b857bac..fe286801 100644
--- a/certmanager/lib/ui/kdhorizontalline.h
+++ b/certmanager/lib/ui/kdhorizontalline.h
@@ -1,5 +1,5 @@
/* -*- Mode: C++ -*-
- KD Tools - a set of useful widgets for Qt
+ KD Tools - a set of useful widgets for TQt
*/
/****************************************************************************
@@ -27,11 +27,11 @@
**
** In addition, as a special exception, the copyright holders give
** permission to link the code of this program with any edition of the
-** Qt library by Trolltech AS, Norway (or with modified versions of Qt
-** that use the same license as Qt), and distribute linked
+** TQt library by Trolltech AS, Norway (or with modified versions of TQt
+** that use the same license as TQt), and distribute linked
** combinations including the two. You must obey the GNU General
** Public License in all respects for all of the code used other than
** Qt. If you modify this file, you may extend this exception to your
** version of the file, but you are not obligated to do so. If you do
** not wish to do so, delete this exception statement from your
** version.
@@ -46,10 +46,11 @@
class KDHorizontalLine : public TQFrame {
Q_OBJECT
- Q_PROPERTY( TQString title READ title WRITE setTitle )
+ TQ_OBJECT
+ TQ_PROPERTY( TQString title READ title WRITE setTitle )
public:
- KDHorizontalLine( TQWidget * parent=0, const char * name=0, WFlags f=0 );
- KDHorizontalLine( const TQString & title, TQWidget * parent=0, const char * name=0, WFlags f=0 );
+ KDHorizontalLine( TQWidget * tqparent=0, const char * name=0, WFlags f=0 );
+ KDHorizontalLine( const TQString & title, TQWidget * tqparent=0, const char * name=0, WFlags f=0 );
~KDHorizontalLine();
TQString title() const { return mTitle; }
@@ -74,7 +75,7 @@ private:
private:
TQString mTitle;
- Qt::AlignmentFlags mAlign;
+ TQt::AlignmentFlags mAlign;
int mLenVisible;
};
@@ -27,11 +27,11 @@
** combinations including the two. You must obey the GNU General
** Public License in all respects for all of the code used other than
-** Qt. If you modify this file, you may extend this exception to your
+** TQt. If you modify this file, you may extend this exception to your
** version of the file, but you are not obligated to do so. If you do
** not wish to do so, delete this exception statement from your